@@ -8,7 +8,7 @@ use Exporter qw(import);
 use Test::BDD::Cucumber::Definitions qw(S :validator);
 use Test::More;
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 our @EXPORT_OK = qw(Var);
 
@@ -44,6 +44,19 @@ sub scenario_var_random {
     return 1;
 }
 
+sub scenario_var_struct {
+    my $self = shift;
+    my ( $name, $jsonpath ) = validator_ns->(@_);
+
+    S->{Var} = __PACKAGE__;
+
+    my $value = S->{Struct}->data_element($jsonpath);
+
+    S->{_Var}->{scenario}->{vars}->{$name} = $value;
+
+    return 1;
+}
+
 sub scenario {
     my $self = shift;
     my ($name) = validator_n->(@_);
